-- Dreamer Clan faction standing script
local spir = require "factions.standing.lib.pirate"
spir.init{
   fct = faction.get("Dreamer Clan"),
}
